from storescrapper.stores.abcdin import AbcDin
from storescrapper.stores.bip import Bip
from storescrapper.stores.clie import Clie
from storescrapper.stores.dell import Dell
from storescrapper.stores.e_notebook import ENotebook
from storescrapper.stores.entel import Entel
from storescrapper.stores.falabella import Falabella
from storescrapper.stores.full_notebook import FullNotebook
from storescrapper.stores.global_mac import GlobalMac
from storescrapper.stores.hp_online import HpOnline
from storescrapper.stores.la_polar import LaPolar
from storescrapper.stores.mac_online import MacOnline
from storescrapper.stores.magens import Magens
from storescrapper.stores.movistar import Movistar
from storescrapper.stores.my_box import MyBox
from storescrapper.stores.notebook_center import NotebookCenter
from storescrapper.stores.packard_bell import PackardBell
from storescrapper.stores.paris import Paris
from storescrapper.stores.pc_express import PcExpress
from storescrapper.stores.pc_factory import PcFactory
from storescrapper.stores.pc_ofertas import PcOfertas
from storescrapper.stores.peta import Peta
from storescrapper.stores.portatil_chile import PortatilChile
from storescrapper.stores.rigam import Rigam
from storescrapper.stores.ripley import Ripley
from storescrapper.stores.sistemax import Sistemax
from storescrapper.stores.syd import Syd
from storescrapper.stores.sym import Sym
from storescrapper.stores.top_pc import TopPc
from storescrapper.stores.ttchile import TtChile
from storescrapper.stores.webco import Webco
from storescrapper.stores.wei import Wei

__all__ = [
    AbcDin.__name__,
    Bip.__name__,
    Clie.__name__,
    Dell.__name__,
    ENotebook.__name__,
    Entel.__name__,
    Falabella.__name__,
    FullNotebook.__name__,
    GlobalMac.__name__,
    HpOnline.__name__,
    LaPolar.__name__,
    MacOnline.__name__,
    Magens.__name__,
    Movistar.__name__,
    MyBox.__name__,
    NotebookCenter.__name__,
    PackardBell.__name__,
    Paris.__name__,
    PcExpress.__name__,
    PcFactory.__name__,
    PcOfertas.__name__,
    Peta.__name__,
    PortatilChile.__name__,
    Rigam.__name__,
    Ripley.__name__,
    Sistemax.__name__,
    Syd.__name__,
    Sym.__name__,
    TopPc.__name__,
    TtChile.__name__,
    Webco.__name__,
    Wei.__name__
]
